%% load features
[D F] = load_sift_features;

N = length(D);

compute = 0;

%% select training set 
% generate the training set using 1/4 of the features
if compute

    T = ceil(N.*rand(round(N*.25),1));
    Ti = zeros(N,1);
    Ti(T) = 1;

    save training_set.mat T TI

else
   
    load training_set
    
end

D_train = single(D(:,Ti==1)');

%% build code book

if compute
    [centers_500, mincenter_500, mindist_500, q2_500, quality_500] = kmeans(D_train, 500);
    save codebook_500 *_500
    clear *_500

    [centers_1000, mincenter_1000, mindist_1000, q2_1000, quality_1000] = kmeans(D_train, 1000);
    save codebook_1000 *_1000
    clear *_1000

    [centers_2000, mincenter_2000, mindist_2000, q2_2000, quality_2000] = kmeans(D_train, 2000);
    save codebook_2000 *_2000
    clear *_2000
    
    [centers_3000, mincenter_3000, mindist_3000, q2_3000, quality_3000] = kmeans(D_train, 3000);
    save codebook_3000 *_3000
    clear *_3000
    
else
    load codebook_500
    load codebook_1000
    load codebook_2000
    load codebook_3000
    
end

%% select testing set (ie everything not it training set)
D_test = single(D(:,Ti~=1)');


%% project onto codebooks and compute error
if compute 
    
    % 500 database
    best_500 = zeros(length(D_test),2);
    for i=1:length(D_test),

        dists = calcdist(centers_500,D_test(i,:));
        [y,j] = min(dists);
        best_500(i,:) = [j y];

    end


    % 1000 database
    best_1000 = zeros(length(D_test),2);
    for i=1:length(D_test),

        dists = calcdist(centers_1000,D_test(i,:));
        [y,j] = min(dists);
        best_1000(i,:) = [j y];

    end


    % 2000 database
    best_2000 = zeros(length(D_test),2);
    for i=1:length(D_test),

        dists = calcdist(centers_2000,D_test(i,:));
        [y,j] = min(dists);
        best_2000(i,:) = [j y];

    end

    
    % 3000 database
    best_3000 = zeros(length(D_test),2);
    for i=1:length(D_test),

        dists = calcdist(centers_3000,D_test(i,:));
        [y,j] = min(dists);
        best_3000(i,:) = [j y];

    end
    
    save bests best_*
else 
    
    load bests
    
end

%% plot some stats
plot([500 1000 2000 3000],[mean(best_500(:,2)) mean(best_1000(:,2)) mean(best_2000(:,2)) mean(best_3000(:,2))])
hold on; plot([500 1000 2000 3000],[max(best_500(:,2)) max(best_1000(:,2)) max(best_2000(:,2)) max(best_3000(:,2))],'r')
hold on; plot([500 1000 2000 3000],[min(best_500(:,2)) min(best_1000(:,2)) min(best_2000(:,2)) min(best_3000(:,2))],'g')

%%
IFT500 = build_inverted_file(centers_500);
IFT1000 = build_inverted_file(centers_1000);
IFT2000 = build_inverted_file(centers_2000);
IFT3000 = build_inverted_file(centers_3000);

save IFTs IFT*
